@@ -158,6 +158,7 @@ static void
 hd_keys_action_power (HDKeysConfig *keys,
                       gpointer     *user_data)
 {
+#ifdef HAVE_LIBOSSO
   osso_rpc_t       retval;
   
   osso_context_t * osso_context =
@@ -177,6 +178,9 @@ hd_keys_action_power (HDKeysConfig *keys,
   {
     g_warning ("Unable to toggle Power menu");
   }
+#else
+  g_warning ("Power key shortcut presses");
+#endif
 }
 
 struct 
