@@ -43,6 +43,7 @@
 #include "hd-select-plugins-dialog.h"
 #include "hd-config.h"
 #include "hd-plugin-manager.h"
+#include "hd-notification-manager.h"
 #include "hd-home-window.h"
 #include "hd-panel-window.h"
 #include "hd-panel-window-dialog.h"
@@ -69,6 +70,7 @@ struct _HDDesktopPrivate
   gchar           *config_file;
   GHashTable      *containers;
   GObject         *pm;
+  GObject         *nm;
 #ifdef HAVE_LIBOSSO
   osso_context_t  *osso_context;
 #endif
@@ -859,6 +861,8 @@ hd_desktop_init (HDDesktop *desktop)
 			         (GDestroyNotify) hd_desktop_free_container_info);
 
   desktop->priv->pm = hd_plugin_manager_new (); 
+
+  desktop->priv->nm = hd_notification_manager_new (); 
 }
 
 static void
@@ -889,6 +893,12 @@ hd_desktop_finalize (GObject *object)
     priv->pm = NULL;
   }
 
+  if (priv->nm)
+  {
+    g_object_unref (priv->nm);
+    priv->nm = NULL;
+  }
+
   G_OBJECT_CLASS (hd_desktop_parent_class)->finalize (object);
 }
 
