@@ -65,8 +65,6 @@
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 
-/* log include */
-#include <log-functions.h>
 
 /* Menu item strings */
 #define AS_HOME_ITEM 		_("tana_fi_home")
